@@ -4,18 +4,21 @@ import time
 import calendar
 import glob
 
-from servicemanager import subprocess
+import subprocess
 from servicemanager.smcontext import ServiceManagerException
 from servicemanager.smprocess import SmProcess
 from servicemanager.service.smplayservice import SmPlayService
 
-def start_one(context, service_name, fatjar, release, proxy, port=None, appendArgs=None):
+
+def start_one(context, service_name, source, fatjar, release, proxy, port=None, appendArgs=None):
     if release:
         run_from = "RELEASE"
     elif fatjar:
         run_from = "SNAPSHOT"
-    else:
+    elif source:
         run_from = "SOURCE"
+    else:
+        run_from = "DEFAULT"
 
     version = release
     if version == "LATEST":
@@ -24,31 +27,42 @@ def start_one(context, service_name, fatjar, release, proxy, port=None, appendAr
     existing_service_status = context.get_service(service_name).status()
 
     if len(existing_service_status) > 0:
-        print "There is already: '" + str(len(existing_service_status)) + "' instance(s) of the service: '" + service_name + "' running"
+        print(
+            (
+                "There is already: '%s' instance(s) of the service: '%s' running"
+                % (str(len(existing_service_status)), service_name)
+            )
+        )
         return False
 
     if context.start_service(service_name, run_from, proxy, port=port, version=version, appendArgs=appendArgs):
         if context.get_service(service_name).is_started_on_default_port():
-            print "Started: " + service_name
+            print(("Started: %s" % service_name))
             return True
 
     return False
 
-def get_start_cmd(context, service_name, fatjar, release, proxy, port=None, appendArgs=None):
+
+def get_start_cmd(context, service_name, source, fatjar, release, proxy, port=None, append_args=None):
     if release:
         run_from = "RELEASE"
     elif fatjar:
         run_from = "SNAPSHOT"
-    else:
+    elif source:
         run_from = "SOURCE"
+    else:
+        run_from = "DEFAULT"
 
     version = release
     if version == "LATEST":
         version = None
 
-    starter = context.get_service_starter(service_name, run_from, proxy, port=port, version=version, appendArgs=appendArgs)
+    starter = context.get_service_starter(
+        service_name, run_from, proxy, port=port, version=version, append_args=append_args,
+    )
     return starter.get_start_command(run_from)
 
+
 def stop_profile(context, profile):
     for service_name in context.application.services_for_profile(profile):
         context.kill(service_name)
@@ -82,12 +96,17 @@ def _wait_for_services(context, service_names, seconds_to_wait):
 
             processes = SmProcess.processes_matching(service.pattern)
             if all(map(service.run_healthcheck, processes)):
-                print "Service '%s' has started successfully" % service.service_name
+                print(("Service '%s' has started successfully" % service.service_name))
                 waiting_for_services.remove(service)
             else:
                 seconds_remaining = end_time - _now()
                 if seconds_remaining % 5 == 0 or seconds_remaining < 10:
-                    print "Waiting for %s to start, %s second%s before timeout" % (service.service_name, seconds_remaining, "s" if seconds_to_wait != 1 else "")
+                    print(
+                        (
+                            "Waiting for %s to start, %s second%s before timeout"
+                            % (service.service_name, seconds_remaining, "s" if seconds_to_wait != 1 else "",)
+                        )
+                    )
 
         if waiting_for_services:
             time.sleep(1)
@@ -98,6 +117,7 @@ def _wait_for_services(context, service_names, seconds_to_wait):
             services_timed_out += [service.service_name]
         raise ServiceManagerException("Timed out starting service(s): %s" % ", ".join(services_timed_out))
 
+
 def clean_logs(context, service_name):
     data = context.service_data(service_name)
     if "location" in data:
@@ -106,7 +126,7 @@ def clean_logs(context, service_name):
 
         num_files = _remove_files_wildcard(sources_logs)
         num_files += _remove_files_wildcard(fatjar_logs)
-        print "Removed %d log files in %s" % (num_files, service_name)
+        print(("Removed %d log files in %s" % (num_files, service_name)))
 
 
 def _remove_files_wildcard(files):
@@ -131,7 +151,7 @@ def _get_running_process_args(context, service_name):
 
     if service.is_started_on_default_port():
         command = "ps -eo args | egrep '%s' | egrep -v 'egrep %s' | awk '{{print  } }'" % (pattern, pattern)
-        ps_command = subprocess.Popen(command, shell=True, stdout=subprocess.PIPE)
+        ps_command = subprocess.Popen(command, shell=True, stdout=subprocess.PIPE, universal_newlines=True)
         ps_output = ps_command.stdout.read()
 
         if ps_output:
@@ -148,22 +168,25 @@ def _get_git_rev(context, service_name):
 
     return ""
 
+
 def display_info(context, service_name):
     arguments = _get_running_process_args(context, service_name)
     git_revision = _get_git_rev(context, service_name)
-    print
-    print "| %s" % service_name
-    print "| %s" % arguments
-    print "| %s" % git_revision
+    print()
+    print(("| %s" % service_name))
+    print(("| %s" % arguments))
+    print(("| %s" % git_revision))
     comments = ""
     if git_revision == "":
         comments += "(No Details) "
     if arguments == "":
         comments += "(Not Running) "
-    print "| " + comments
+    print(("| %s" % comments))
 
 
-def start_and_wait(service_resolver, context, start, fatjar, release, proxy, port, seconds_to_wait, append_args):
+def start_and_wait(
+    service_resolver, context, start, source, fatjar, release, proxy, port, seconds_to_wait, append_args,
+):
 
     all_services = service_resolver.resolve_services_from_array(start)
     for service_name in all_services:
@@ -171,18 +194,26 @@ def start_and_wait(service_resolver, context, start, fatjar, release, proxy, por
             append_args_for_this_service = None
             if append_args is not None:
                 append_args_for_this_service = append_args.get(service_name, None)
-            start_one(context, service_name, fatjar, release, proxy, overridden_port(start, port), append_args_for_this_service)
+            start_one(
+                context,
+                service_name,
+                source,
+                fatjar,
+                release,
+                proxy,
+                overridden_port(start, port),
+                append_args_for_this_service,
+            )
         else:
-            print "The requested service %s does not exist" % service_name
+            print(("The requested service %s does not exist" % service_name))
 
     if seconds_to_wait:
         _wait_for_services(context, all_services, seconds_to_wait)
 
-    print "All services passed healthcheck"
+    print("\nAll services passed healthcheck")
 
 
 def get_log_file(context, service_name):
-
     def mtime(path):
         try:
             return os.path.getmtime(path)
@@ -191,13 +222,14 @@ def get_log_file(context, service_name):
 
     data = context.service_data(service_name)
     if "location" in data:
-        logs = [context.application.workspace + data["location"] + "/logs/stdout.txt",
-                context.application.workspace + data["location"] + "/target/logs/stdout.txt",
-                SmPlayService.unzipped_dir_path(context, data["location"]) + "/logs/stdout.txt"]
+        logs = [
+            context.application.workspace + data["location"] + "/logs/stdout.txt",
+            context.application.workspace + data["location"] + "/target/logs/stdout.txt",
+            SmPlayService.unzipped_dir_path(context, data["location"]) + "/logs/stdout.txt",
+        ]
         if not any([os.path.exists(log) for log in logs]):
             raise ServiceManagerException("Cannot find log files for %s" % service_name)
         else:
             return sorted(logs, key=mtime, reverse=True)[0]
     else:
         raise ServiceManagerException("Cannot find a location for %s" % service_name)
-
