@@ -5,29 +5,38 @@ import re
 import requests
 import types
 
-from servicemanager.service.smservice import SmServiceStarter, SmService, SmServiceStatus
-from servicemanager.smprocess import SmProcess, kill_pid
-from servicemanager import subprocess
+from servicemanager.service.smservice import (
+    SmServiceStarter,
+    SmService,
+    SmServiceStatus,
+)
+from servicemanager.smprocess import SmProcess, kill_processes_matching
+import subprocess
 
 
 class SmExternalServiceStarter(SmServiceStarter):
-
     def process_arguments(self):
         pass
 
     def __init__(self, context, service_name, append_args):
         SmServiceStarter.__init__(self, context, service_name, "external", append_args)
         if not "cmd" in self.service_data:
-            context.log("Could not start 'external' service '" + service_name + "', 'cmd' is missing from services.json")
+            context.log(
+                "Could not start 'external' service '" + service_name + "', 'cmd' is missing from services.json"
+            )
         self.cmd = self.service_data["cmd"]
 
     def get_start_command(self, context=None):
         if self.append_args:
-            if isinstance(self.append_args, types.ListType):
+            if isinstance(self.append_args, list):
                 return self.cmd + self.append_args
             else:
+                self.log(
+                    "WARNING: I was passed a non list for append args of '"
+                    + str(self.append_args)
+                    + "' I dont know what to do with this"
+                )
                 return self.cmd
-                self.log("WARNING: I was passed a non list for append args of '" + str(self.append_args) + "' I dont know what to do with this")
         else:
             return self.cmd
 
@@ -41,13 +50,19 @@ class SmExternalServiceStarter(SmServiceStarter):
                 location = self.service_data["location"]
             microservice_path = os.path.join(self.context.application.workspace, location)
             os.chdir(microservice_path)
-            return subprocess.Popen(" ".join(self.get_start_command()), cwd=microservice_path, env=os.environ.copy(), shell=True).pid
-        except Exception, e:
+
+            return subprocess.Popen(
+                self.get_start_command(),
+                cwd=microservice_path,
+                env=os.environ.copy(),
+                shell=False,
+                universal_newlines=True,
+            ).pid
+        except Exception as e:
             self.log("Could not start service due to exception: " + str(e))
 
 
 class SmExternalService(SmService):
-
     def __init__(self, context, service_name):
         SmService.__init__(self, context, service_name, "external")
         self.pattern = self.required_data("pattern")
@@ -55,13 +70,8 @@ class SmExternalService(SmService):
     def get_pattern(self):
         return self.pattern
 
-    def stop(self):
-        processes = SmProcess.processes_matching(self.pattern)
-
-        for process in processes:
-            kill_pid(self.context, process.ppid)
-            kill_pid(self.context, process.pid)
-            print "name: %s\tppid: %s\tpid: %s\tuptime: %s" % (self.service_name, process.ppid, process.pid, process.uptime)
+    def stop(self, wait=False):
+        kill_processes_matching(self.pattern, self.context, wait == True, wait)
 
     def clean_up(self):
         pass
@@ -86,9 +96,8 @@ class SmExternalService(SmService):
         else:
             return None
 
-    def status(self):
-
-        processes = SmProcess.processes_matching(self.pattern)
+    def status(self, all_processes=None):
+        processes = SmProcess.processes_matching(self.pattern, all_processes)
 
         if len(processes) == 0:
             return []
@@ -100,8 +109,11 @@ class SmExternalService(SmService):
             hc_result = self.run_healthcheck(process)
             healthcheck = SmServiceStatus.HEALTHCHECK_NONE
             if hc_result is not None:
-                healthcheck = SmServiceStatus.HEALTHCHECK_PASS if self.run_healthcheck(process) else SmServiceStatus.HEALTHCHECK_BOOT
+                healthcheck = (
+                    SmServiceStatus.HEALTHCHECK_PASS
+                    if self.run_healthcheck(process)
+                    else SmServiceStatus.HEALTHCHECK_BOOT
+                )
             return SmServiceStatus.for_process(self.service_name, process, "", "", "", "", healthcheck)
 
-
-        return map(_status_for_process, processes)
+        return list(map(_status_for_process, processes))
