@@ -7,7 +7,11 @@ from abc import abstractmethod
 import requests
 
 from servicemanager.smprocess import SmProcess, kill_pid
-from servicemanager.service.smservice import SmService, SmMicroServiceStarter, SmServiceStatus
+from servicemanager.service.smservice import (
+    SmService,
+    SmMicroServiceStarter,
+    SmServiceStatus,
+)
 from servicemanager.smrepo import clone_repo_if_requred
 
 
@@ -15,8 +19,32 @@ class SmJvmServiceStarter(SmMicroServiceStarter):
 
     test_id_param = "service.manager.testId"
 
-    def __init__(self, context, service_name, expected_service_type, run_from, port, classifier, service_mapping_ports, version, proxy, append_args):
-        SmMicroServiceStarter.__init__(self, context, service_name, expected_service_type, run_from, port, classifier, service_mapping_ports, version, proxy, append_args)
+    def __init__(
+        self,
+        context,
+        service_name,
+        expected_service_type,
+        run_from,
+        port,
+        classifier,
+        service_mapping_ports,
+        version,
+        proxy,
+        append_args,
+    ):
+        SmMicroServiceStarter.__init__(
+            self,
+            context,
+            service_name,
+            expected_service_type,
+            run_from,
+            port,
+            classifier,
+            service_mapping_ports,
+            version,
+            proxy,
+            append_args,
+        )
 
     def start(self, appendArgs=None):
         if self.run_from == "SOURCE":
@@ -30,7 +58,7 @@ class SmJvmServiceStarter(SmMicroServiceStarter):
 
     def process_arguments(self):
         run_from = self.run_from
-        if self.run_from=="RELEASE":
+        if self.run_from == "RELEASE":
             run_from = (self.version or "UNKNOWN") + "-" + run_from
         jvm_args = ["-Dservice.manager.serviceName=%s" % self.service_name]
         jvm_args += ["-Dservice.manager.runFrom=%s" % run_from]
@@ -49,10 +77,9 @@ class SmJvmServiceStarter(SmMicroServiceStarter):
 
 
 class SmJvmService(SmService):
-
     def __init__(self, context, service_name, expected_service_type):
         SmService.__init__(self, context, service_name, expected_service_type)
-        self.pattern = "service.manager.serviceName=%s " % self.service_name
+        self.pattern = "service.manager.serviceName=%s$" % self.service_name
         self.default_port = self.required_data("defaultPort")
         self.healthcheck = self.required_data("healthcheck")
 
@@ -75,18 +102,22 @@ class SmJvmService(SmService):
     def get_pattern(self):
         return self.pattern
 
-    def status(self):
-        processes = SmProcess.processes_matching(self.pattern)
+    def status(self, all_processes=None):
+        processes = SmProcess.processes_matching(self.pattern, all_processes)
 
         def _status_for_process(process):
-            port = process.extract_integer_argument('-D%s=(\d*)' % self.get_port_argument(), self.default_port)
-            test_id = process.extract_argument('-Dservice.manager.testId=([^ ]+)', "")
-            run_from = process.extract_argument('-Dservice.manager.runFrom=([^ ]+)', "")
-            features = process.extract_arguments('-Dfeature.([^ =]+)=true', "")
-            healthcheck = SmServiceStatus.HEALTHCHECK_PASS if self.run_healthcheck(process) else SmServiceStatus.HEALTHCHECK_BOOT
-            return SmServiceStatus.for_process(self.service_name, process, port, test_id, run_from, features, healthcheck)
+            port = process.extract_integer_argument("-D%s=(\d*)" % self.get_port_argument(), self.default_port)
+            test_id = process.extract_argument("-Dservice.manager.testId=([^ ]+)", "")
+            run_from = process.extract_argument("-Dservice.manager.runFrom=([^ ]+)", "")
+            features = process.extract_arguments("-Dfeature.([^ =]+)=true", "")
+            healthcheck = (
+                SmServiceStatus.HEALTHCHECK_PASS if self.run_healthcheck(process) else SmServiceStatus.HEALTHCHECK_BOOT
+            )
+            return SmServiceStatus.for_process(
+                self.service_name, process, port, test_id, run_from, features, healthcheck,
+            )
 
-        return map(_status_for_process, processes)
+        return list(map(_status_for_process, processes))
 
     def request_running_service_details_on_default_port(self):
         url = self.get_details_url().replace("${port}", str(self.default_port))
@@ -110,11 +141,15 @@ class SmJvmService(SmService):
     def get_default_healthcheck_port(self):
         return self.default_port
 
-    def stop(self):
+    def stop(self, wait=False):
         for process in SmProcess.processes_matching(self.pattern):
-            kill_pid(self.context, process.ppid)
-            kill_pid(self.context, process.pid)
-            print "name: %s\tppid: %s\tpid: %s\tuptime: %s" % (self.service_name, process.ppid, process.pid, process.uptime)
+            kill_pid(self.context, process.ppid, wait=wait)
+            kill_pid(self.context, process.pid, wait=wait)
+            self.context.log(
+                "name: %s\tppid: %s\tpid: %s\tuptime: %s"
+                % (self.service_name, process.ppid, process.pid, process.uptime),
+                True,
+            )
         self.post_stop()
 
     def run_healthcheck(self, process):
