@@ -5,23 +5,63 @@ import zipfile
 import signal
 import time
 import re
+import sys
 
 import requests
 
-from servicemanager import subprocess
-from smservice import SmService, SmMicroServiceStarter, SmServiceStatus
-from servicemanager.smprocess import SmProcess
-from servicemanager.smfile import force_chdir, force_pushdir, remove_if_exists, remove_folder_if_exists, makedirs_if_not_exists
-from servicemanager.smnexus import SmNexus
+import subprocess
+from .smservice import SmService, SmMicroServiceStarter, SmServiceStatus
+from servicemanager.smprocess import SmProcess, kill_pid
+from servicemanager.smfile import (
+    force_chdir,
+    remove_if_exists,
+    remove_folder_if_exists,
+    makedirs_if_not_exists,
+)
+from servicemanager.smartifactory import SmArtifactory
 from servicemanager.smrepo import clone_repo_if_requred
 
 
+def _is_python_3():
+    proc = subprocess.Popen(["python", "--version"],
+                          shell=False,
+                          env=os.environ.copy(),
+                          stdout=subprocess.PIPE,
+                          stderr=subprocess.PIPE,
+                          close_fds=True,
+                          universal_newlines=True)
+    pyver = proc.stdout.readline().lower()
+    return pyver.startswith("python 3")
+
 class SmPythonServiceStarter(SmMicroServiceStarter):
 
     PROCESS_STARTUP_TIMEOUT_SECONDS = 90
 
-    def __init__(self, context, service_name, run_from, port, classifier, service_mapping_ports, version, proxy=None, append_args=None):
-        SmMicroServiceStarter.__init__(self, context, service_name, "assets", run_from, port, classifier, service_mapping_ports, version, proxy, append_args)
+    def __init__(
+        self,
+        context,
+        service_name,
+        run_from,
+        port,
+        classifier,
+        service_mapping_ports,
+        version,
+        proxy=None,
+        append_args=None,
+    ):
+        SmMicroServiceStarter.__init__(
+            self,
+            context,
+            service_name,
+            "assets",
+            run_from,
+            port,
+            classifier,
+            service_mapping_ports,
+            version,
+            proxy,
+            append_args,
+        )
 
         if not self.port:
             self.port = self.service_data["defaultPort"]
@@ -29,6 +69,9 @@ class SmPythonServiceStarter(SmMicroServiceStarter):
     def process_arguments(self):
         pass
 
+    def get_start_command(self, run_from):
+        return self.service_data["binary"]["cmd"]
+
     def _start_from_binary(self):
         assets_target_path = self.context.get_microservice_target_path(self.service_name)
         assets_path = self.context.application.workspace + self.service_data["location"]
@@ -39,16 +82,41 @@ class SmPythonServiceStarter(SmMicroServiceStarter):
         force_chdir(assets_target_path)
 
         if not self.context.offline:
-            nexus = SmNexus(self.context, self.service_name)
-            versions = nexus.get_all_versions(self.run_from)
+            artifactory = SmArtifactory(self.context, self.service_name)
+
+            if self.version:
+                versions = [self.version]
+            elif self.context.assets_versions:
+                versions = self.context.assets_versions
+                self.log("Starting assets versions: %s" % (", ".join(versions)), True)
+            else:
+                versions = artifactory.find_all_versions(self.run_from)
+                self.log("Starting assets versions: %s" % (", ".join(versions)), True)
+
             for version in versions:
-                nexus.download_jar_if_necessary(self.run_from, version)
+                self.context.log("\nStarting assets version: %s" % version)
+                artifactory.download_jar_if_necessary(self.run_from, version)
             self._unzip_assets(versions)
 
         cmd_with_params = self.service_data["binary"]["cmd"]
+        if _is_python_3():
+            py3cmd = self.service_data["binary"].get("py3_cmd")
+            if py3cmd is not None:
+                cmd_with_params = py3cmd
+
+        self.log("starting %s..." % cmd_with_params)
+
         makedirs_if_not_exists("logs")
         with open("logs/stdout.txt", "wb") as out, open("logs/stderr.txt", "wb") as err:
-            return subprocess.Popen(cmd_with_params[0].split(), shell=False, env=os.environ.copy(), stdout=out, stderr=err, close_fds=True).pid
+            return subprocess.Popen(
+                cmd_with_params[0].split(),
+                shell=False,
+                env=os.environ.copy(),
+                stdout=out,
+                stderr=err,
+                close_fds=True,
+                universal_newlines=True,
+            ).pid
 
     def _start_from_sources(self):
 
@@ -56,8 +124,8 @@ class SmPythonServiceStarter(SmMicroServiceStarter):
         assets_path = self.context.application.workspace + service_data["location"]
 
         cmd_with_params = self.service_data["sources"]["cmd"]
-        force_pushdir(assets_path)
-        run_from_file = open("RUNNING_FROM", 'w')
+        force_chdir(assets_path)
+        run_from_file = open("RUNNING_FROM", "w")
         run_from_file.write(self.run_from)
         run_from_file.close()
 
@@ -65,23 +133,27 @@ class SmPythonServiceStarter(SmMicroServiceStarter):
         seconds_remaining = SmPythonServiceStarter.PROCESS_STARTUP_TIMEOUT_SECONDS
 
         with open("logs/stdout.txt", "wb") as out, open("logs/stderr.txt", "wb") as err:
-            subprocess.Popen(cmd_with_params, shell=False, env=os.environ.copy(), stdout=out, stderr=err, close_fds=True)
+            subprocess.Popen(
+                cmd_with_params, shell=False, env=os.environ.copy(), stdout=out, stderr=err, close_fds=True,
+            )
 
         while seconds_remaining > 0 and not len(SmProcess.processes_matching("grunt")) > 0:
             time.sleep(1)
             seconds_remaining -= 1
             if seconds_remaining < 10 or seconds_remaining % 5 == 0:
-                self.log("Waiting for Assets service to start: %s second%s before timeout" % (
-                    seconds_remaining, "s" if seconds_remaining > 1 else ""))
+                self.log(
+                    "Waiting for Assets service to start: %s second%s before timeout"
+                    % (seconds_remaining, "s" if seconds_remaining > 1 else "")
+                )
         if len(SmProcess.processes_matching("grunt")) == 1:
             process = SmProcess.processes_matching("grunt")
             for i, v in enumerate(process):
-                    return v.pid
+                return v.pid
 
     def _unzip_assets(self, versions):
         service_data = self.service_data
         assets_zip_path = self.context.get_microservice_target_path(self.service_name)
-        force_pushdir(assets_zip_path)
+        force_chdir(assets_zip_path)
         unzipped_dir = "assets"
         if not os.path.exists(unzipped_dir):
             os.makedirs(unzipped_dir)
@@ -91,7 +163,7 @@ class SmPythonServiceStarter(SmMicroServiceStarter):
             extracted_dir = version
             if not os.path.exists(assets_zip_path + "/assets/" + extracted_dir):
                 os.makedirs(extracted_dir)
-                zipfile.ZipFile(zip_filename, 'r').extractall(extracted_dir)
+                zipfile.ZipFile(zip_filename, "r").extractall(extracted_dir)
                 shutil.move(extracted_dir, unzipped_dir)
         target_dir = unzipped_dir
         return target_dir
@@ -108,7 +180,6 @@ class SmPythonServiceStarter(SmMicroServiceStarter):
 
 
 class SmPythonService(SmService):
-
     @staticmethod
     def unzipped_dir_path(context, location):
         return context.application.play_extraction_dir + location + "_" + context.instance_id
@@ -120,22 +191,18 @@ class SmPythonService(SmService):
         self.healthcheck = self.required_data("healthcheck")
         self.pattern = SmPythonService.get_pattern(self)
 
-    def stop(self):
+    def stop(self, wait=False):
 
-        ps_command = "ps axo pid,command | grep '%s' | grep -v 'grep' | awk '{print $1}'" % SmPythonService.get_pattern(self)
+        procs = SmProcess.processes_matching(SmPythonService.get_pattern(self), None)
 
-        ps = subprocess.Popen(ps_command, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-        pid_values = map(int, ps.stdout.read().split("\n")[:-1])
-
-        if len(pid_values) == 0:
+        if len(procs) == 0:
             return
 
-        self.log("Killing service '%s' (pid = %s)..." % (self.service_data["name"], str(pid_values)))
-
-        for pid_int in pid_values:
-            os.kill(pid_int, signal.SIGINT)
-            self.log("PID  %d killed" % pid_int)
+        self.log("Stopping '%s'..." % (self.service_data["name"]), True)
 
+        for proc in procs:
+            kill_pid(self.context, proc.pid, wait=wait)
+            self.log("PID  %d killed" % proc.pid, True)
 
     def clean_up(self):
         unzip_path = SmPythonService.unzipped_dir_path(self.context, self.service_data["location"])
@@ -145,8 +212,8 @@ class SmPythonService(SmService):
         # TODO: implement git revision stuff for python or remove the feature
         return None
 
-    def status(self):
-        processes = SmProcess.processes_matching(SmPythonService.get_pattern(self))
+    def status(self, all_processes=None):
+        processes = SmProcess.processes_matching(SmPythonService.get_pattern(self), all_processes)
 
         if len(processes) == 0:
             return []
@@ -155,10 +222,12 @@ class SmPythonService(SmService):
             self.log("POSSIBLE PROBLEM: Found more than one process")
 
         def _status_for_process(process):
-            healthcheck = SmServiceStatus.HEALTHCHECK_PASS if self.run_healthcheck(None) else SmServiceStatus.HEALTHCHECK_BOOT
+            healthcheck = (
+                SmServiceStatus.HEALTHCHECK_PASS if self.run_healthcheck(None) else SmServiceStatus.HEALTHCHECK_BOOT
+            )
             return SmServiceStatus.for_process(self.service_name, process, self.default_port, "", "", "", healthcheck)
 
-        return map(_status_for_process, processes)
+        return list(map(_status_for_process, processes))
 
     def run_healthcheck(self, process):
         port = self.default_port
@@ -177,4 +246,7 @@ class SmPythonService(SmService):
         return len(SmProcess.processes_matching(SmPythonService.get_pattern(self))) > 0
 
     def get_pattern(self):
-        return self.service_data["pattern"]
\ No newline at end of file
+        if _is_python_3():
+            return self.service_data.get("py3_pattern")
+        else:
+            return self.service_data["pattern"]
