@@ -20,10 +20,3 @@ def makedirs_if_not_exists(path):
 def force_chdir(path):
     makedirs_if_not_exists(path)
     os.chdir(path)
-
-
-def force_pushdir(path):
-    curdir = os.getcwd()
-    makedirs_if_not_exists(path)
-    os.chdir(path)
-    return curdir
