@@ -2,27 +2,55 @@
 from signal import SIGINT, SIGKILL
 import os
 import re
+import time
 
-from servicemanager import subprocess
+import subprocess
 
 
-def kill_pid(context, pid, force=False):
+def kill_pid(context, pid, force=False, wait=False):
 
     if _is_system_or_smserver_or_test_process(pid):
         return "Not allowed to kill system, test or smserver process (pid = %d)" % pid
 
     try:
+        context.log("killing pid: " + str(pid), True)
         if force:
             os.kill(pid, SIGKILL)
         else:
             os.kill(pid, SIGINT)
 
-    except Exception, e:
+        if wait:
+            os.waitpid(pid, 0)
+
+    except Exception as e:
         error = "Could not kill pid: " + str(pid) + " because of exception: " + str(e)
         context.log(error)
         return error
 
 
+def kill_processes_matching(pattern, context, force=False, wait=False):
+
+    # Be polite and ask the processes to quit
+    processes = SmProcess.processes_matching(pattern)
+    for process in processes:
+        kill_pid(context, process.pid, False, False)
+
+    waited = 0.0
+    time_between_polls = 0.1
+    timeout = 15
+
+    while waited < timeout:
+        processes = SmProcess.processes_matching(pattern)
+        if len(processes) == 0:
+            return
+        time.sleep(time_between_polls)
+        waited = waited + time_between_polls
+
+    if force:
+        for process in processes:
+            kill_pid(context, process.pid, force, wait)
+
+
 def _is_system_or_smserver_or_test_process(pid):
 
     if pid == 1:
@@ -46,45 +74,63 @@ def _is_system_or_smserver_or_test_process(pid):
     if _is_pycharm_related_process(pid):
         return True
 
+    if _is_upstart_process(pid):
+        return True
+
+    if _is_systemd_process(pid):
+        return True
+
     return False
 
 
 def _is_pid_in_list(pid, command):
-    ps_command = subprocess.Popen(command, shell=True, stdout=subprocess.PIPE)
+    ps_command = subprocess.Popen(command, shell=True, stdout=subprocess.PIPE, universal_newlines=True)
     ps_output = ps_command.stdout.read()
     ps_pid_str = ps_output.strip()
     for process in ps_pid_str.split("\n"):
         if process and int(process) == pid:
             return True
+    ps_command.stdout.close()
     return False
 
+
 def _is_init_process(pid):
-    command = "ps -eo ppid,pid,etime,rss,args | grep 'init --user' | grep -v 'grep init --user' | grep -v indicator | awk '{print $2 }'"
+    command = r"ps -eo ppid,pid,etime,rss,args | grep 'init --user' | grep -v 'grep init --user' | grep -v indicator | awk '{print $2 }'"
     return _is_pid_in_list(pid, command)
 
 
 def _is_smserver_process(pid):
-    command = "ps -eo pid,args | grep %d | grep 'smserver\.py' | awk '{print $1}'" % pid
+    command = r"ps -eo pid,args | grep %d | grep 'smserver\.py' | awk '{print $1}'" % pid
     return _is_pid_in_list(pid, command)
 
 
 def _is_pytest_process(pid):
-    command = "ps -eo pid,args | grep %d | grep 'py\.test' | awk '{print $1}'" % pid
+    command = r"ps -eo pid,args | grep %d | grep 'py\.test' | awk '{print $1}'" % pid
     return _is_pid_in_list(pid, command)
 
 
 def _is_pycharm_test_process(pid):
-    command = "ps -eo pid,args | grep %d | grep 'pytestrunner\.py' | awk '{print $1}'" % pid
+    command = r"ps -eo pid,args | grep %d | grep 'pytestrunner\.py' | awk '{print $1}'" % pid
     return _is_pid_in_list(pid, command)
 
 
 def _is_pycharm_process(pid):
-    command = "ps -eo pid,args | grep %d | grep 'pydevd\.py' | awk '{print $1}'" % pid
+    command = r"ps -eo pid,args | grep %d | grep 'pydevd\.py' | awk '{print $1}'" % pid
     return _is_pid_in_list(pid, command)
 
 
 def _is_pycharm_related_process(pid):
-    command = "ps -eo pid,args | grep %d | grep 'pycharm' | awk '{print $1}'" % pid
+    command = r"ps -eo pid,args | grep %d | grep 'pycharm' | awk '{print $1}'" % pid
+    return _is_pid_in_list(pid, command)
+
+
+def _is_upstart_process(pid):
+    command = r"ps -eo pid,args | grep %d | grep 'upstart' | awk '{print $1}'" % pid
+    return _is_pid_in_list(pid, command)
+
+
+def _is_systemd_process(pid):
+    command = r"ps -eo pid,args | grep %d | grep 'systemd --user' | awk '{print $1}'" % pid
     return _is_pid_in_list(pid, command)
 
 
@@ -95,7 +141,7 @@ def kill_by_test_id(context, force):
         service_name = _get_service_name_for_pid(pid)
         if force:
             if service_name:
-                context.log("Force killing %s (pid: %s)" % (service_name, pid))    
+                context.log("Force killing %s (pid: %s)" % (service_name, pid))
             else:
                 context.log("Force killing pid: %s (unknown/missing service name)" % pid)
         context.log("killing %s" % service_name)
@@ -115,21 +161,21 @@ def _get_process_ids_for_test(context):
 
 
 def _get_process_ids_for_processes_matching(regex):
-    command = "ps -eo pid,args | grep '%s' |grep -v 'grep %s' |  awk '{print $1}'" % (regex, regex)
-    ps_command = subprocess.Popen(command, shell=True, stdout=subprocess.PIPE)
-    stdout, stderr = ps_command.communicate()
-
-    return map(int, stdout.split("\n")[:-1])
+    command = "ps -eo pid,args | grep '%s' |grep -v 'grep %s' |  awk '{print $1}'" % (regex, regex,)
+    ps_command = subprocess.Popen(command, shell=True, stdout=subprocess.PIPE, universal_newlines=True)
+    stdout, _ = ps_command.communicate()
+    rv = list(map(int, stdout.split("\n")[:-1]))
+    return rv
 
 
 def _get_service_name_for_pid(pid):
     command = "ps -p %s -o command,args" % pid
 
-    ps_command = subprocess.Popen(command, shell=True, stdout=subprocess.PIPE)
-    stdout, stderr = ps_command.communicate()
+    ps_command = subprocess.Popen(command, shell=True, stdout=subprocess.PIPE, universal_newlines=True)
+    stdout, _ = ps_command.communicate()
     ps_output = stdout.split()
 
-    p = re.compile('-Dservice\.manager\.serviceName=([A-Z_]+)')
+    p = re.compile("-Dservice\.manager\.serviceName=([A-Z_]+)")
 
     for i in ps_output:
         t = p.match(i)
@@ -140,6 +186,27 @@ def _get_service_name_for_pid(pid):
 
 
 class SmProcess:
+    @classmethod
+    def all_processes(cls):
+        command = "ps -eo ppid,pid,etime,rss,args"
+        ps_command = subprocess.Popen(command, shell=True, stdout=subprocess.PIPE, universal_newlines=True)
+        stdout, _ = ps_command.communicate()
+        ps_output = stdout.split("\n")[:-1]
+
+        def process_line_to_object(process_line):
+            values = process_line.strip().split()
+            return SmProcess(int(values[0]), int(values[1]), values[2], values[3], values[4:])
+
+        return list(map(process_line_to_object, ps_output[1:]))
+
+    @staticmethod
+    def find_in_command_line(args, r):
+        for arg in args:
+            if r.search(arg):
+                return True
+        if r.search(" ".join(args)):
+            return True
+        return False
 
     def __init__(self, ppid, pid, uptime, mem, args):
         self.ppid = ppid
@@ -149,19 +216,10 @@ class SmProcess:
         self.args = args
 
     @staticmethod
-    def processes_matching(regex):
-        command = "ps -eo ppid,pid,etime,rss,args | egrep -e '%s' | grep -vi 'grep -e'" % regex
-        ps_command = subprocess.Popen(command, shell=True, stdout=subprocess.PIPE)
-        stdout, stderr = ps_command.communicate()
-        ps_output = stdout.split("\n")[:-1]
-
-        def process_line_to_object(process_line):
-            values = process_line.strip().split()
-            return SmProcess(int(values[0]), int(values[1]), values[2], values[3], values[4:])
-
-        ret = map(process_line_to_object, ps_output)
-
-        return ret
+    def processes_matching(regex, processes=None):
+        processes = processes or SmProcess.all_processes()
+        r = re.compile(regex)
+        return [p for p in processes if SmProcess.find_in_command_line(p.args, r)]
 
     def has_argument(self, argument):
         return argument in self.args
